import { RegSuitConfiguration } from "./config-manager";
import { RegLogger } from "./logger";
import { KeyGeneratorPlugin, NotifierPlugin, PublishResult, PublisherPlugin } from "./plugin";
import { CoreConfig, CreateQuestionsOptions } from "./core-interface";
export interface PluginMetadata {
    moduleId: string;
    [key: string]: any;
}
export interface ComparisonResult {
    failedItems: string[];
    newItems: string[];
    deletedItems: string[];
    passedItems: string[];
    expectedItems: string[];
    actualItems: string[];
    diffItems: string[];
    actualDir: string;
    expectedDir: string;
    diffDir: string;
}
export declare class RegSuitCore {
    _keyGenerator?: KeyGeneratorPlugin<any>;
    _publisher?: PublisherPlugin<any>;
    notifiers: NotifierPlugin<any>[];
    _logger: RegLogger;
    _config: RegSuitConfiguration;
    _pluginHolders: PluginMetadata[];
    constructor();
    _loadPlugins(): void;
    _loadPlugin(name: string): void;
    _getInstalledPlugins(): string[];
    createQuestions(opt: CreateQuestionsOptions): {
        name: string;
        questions: any;
        prepare: (inquireResult: any) => Promise<any>;
    }[];
    persistMergedConfig(opt: {
        core?: CoreConfig;
        pluginConfigs: {
            name: string;
            config: any;
        }[];
    }): void;
    init(configFileName?: string): void;
    _initKeyGenerator(): void;
    _initPublisher(): void;
    _loadConfig(configFileName?: string): RegSuitConfiguration;
    runAll(): void;
    compare(): Promise<void | ComparisonResult>;
    getExpectedKey(): Promise<string | null>;
    getActualKey(): Promise<string>;
    fetch(keyForExpected: string | null): Promise<void> | undefined;
    publish(keyForActual: string): Promise<PublishResult | null>;
    notify(result: PublishResult | null): void;
}
